@@ -42,11 +42,10 @@ class Cache:
         self.fullTrainingData = 0
         self.normalizeOutput = True
         self.sobolGeneration = True
-        self.graphSpearman = False
         self.continueMCMC = False
         self.errorBias = True
-        self.altFeatures = False
-        self.altFeatureNames = []
+        self.altScores = False
+        self.altScoreNames = []
         self.progress_headers = [
             "Generation",
             "Population",
@@ -181,8 +180,6 @@ class Cache:
         self.sobolGeneration = bool(
             self.settings.get("soboloGeneration", True)
         ) or bool(self.settings.get("sobolGeneration", True))
-        self.graphSpearman = bool(self.settings.get("graphSpearman", False))
-        self.scoreMCMC = self.settings.get("scoreMCMC", "sse")
 
         self.continueMCMC = bool(self.settings.get("continueMCMC", False))
         self.MCMCTauMult = int(self.settings.get("MCMCTauMult", 50))
@@ -244,7 +241,7 @@ class Cache:
         meta_mask_seq = []
 
         for idx, experiment in enumerate(self.settings["experiments"]):
-            for feature in experiment["features"]:
+            for feature in experiment["scores"]:
                 if feature["type"] in self.scores:
                     settings = self.scores[feature["type"]].get_settings(feature)
                     meta_mask = settings.meta_mask
@@ -270,6 +267,25 @@ class Cache:
             if "csv" not in self.settings:
                 self.settings["csv"] = "results.csv"
 
+            #convert features to scores
+            for experiment in self.settings['experiments']:
+                if "features" in experiment:
+                    experiment['scores'] = experiment['features']
+
+                    for score in experiment['scores']:
+                        if "isotherm" in score:
+                            score['output_path'] = score['isotherm']
+
+                if "isotherm" in experiment:
+                    experiment["output_path"] = experiment["isotherm"]
+
+                if "featuresAlt" in experiment:
+                    experiment['scoresAlt'] = experiment['featureAlt']
+
+                    for score in experiment['scoresAlt']:
+                        if "isotherm" in score:
+                            score['output_path'] = score['isotherm']
+
             if self.settings["searchMethod"] == "Gradient":
                 self.settings["population"] = 1
             else:
@@ -322,7 +338,7 @@ class Cache:
         for idx, experiment in enumerate(self.settings["experiments"]):
             experimentName = experiment["name"]
             experiment["headers"] = []
-            for feature in experiment["features"]:
+            for feature in experiment["scores"]:
                 if feature["type"] in self.scores:
                     temp = self.scores[feature["type"]].headers(experimentName, feature)
 
@@ -383,9 +399,9 @@ class Cache:
 
     def add_units_features_alt(self, units_used, features_alt):
         for feature_alt in features_alt:
-            self.add_units_isotherm(units_used, feature_alt.get("isotherm", ""))
-            for feature in feature_alt["features"]:
-                self.add_units_isotherm(units_used, feature.get("isotherm", ""))
+            self.add_units_isotherm(units_used, feature_alt.get("output_path", ""))
+            for feature in feature_alt["scores"]:
+                self.add_units_isotherm(units_used, feature.get("output_path", ""))
                 self.add_units_isotherm(units_used, feature.get("unit_name", ""))
 
     def add_units_error_model(self, error_models, target):
@@ -416,6 +432,8 @@ class Cache:
 
         units_used = []
 
+        residence_time_unit = int(experiment.get('residence_time_unit', 1))
+
         if sim is None:
             sim = Cadet()
             sim.filename = Path(experiment["HDF5"]).as_posix()
@@ -430,26 +448,28 @@ class Cache:
         conn = numpy.reshape(conn, [-1, self.connectionNumberEntries])
 
         # find all the entries that connect to the column
-        filter = conn[:, 1] == 1
+        filter = conn[:, 1] == residence_time_unit
 
         # flow is the sum of all flow rates that connect to this column which is in the last column
         flow = sum(conn[filter, -1])
 
-        if sim.root.input.model.unit_001.unit_type == b"CSTR":
-            volume = float(sim.root.input.model.unit_001.init_volume)
+        unit = sim.root.input.model[f'unit_{residence_time_unit:03d}']
+
+        if unit.unit_type == b"CSTR":
+            volume = float(unit.init_volume)
 
             CV_time = volume / flow
 
         else:
             # CV needs to be based on superficial velocity not interstitial velocity
-            length = float(sim.root.input.model.unit_001.col_length)
+            length = float(unit.col_length)
 
-            velocity = sim.root.input.model.unit_001.velocity
+            velocity = unit.velocity
             if velocity == {}:
                 velocity = 1.0
             velocity = float(velocity)
 
-            area = sim.root.input.model.unit_001.cross_section_area
+            area = unit.cross_section_area
             if area == {}:
                 area = 1.0
             area = float(area)
@@ -465,7 +485,7 @@ class Cache:
 
         if dataFromSim:
             temp["time"], temp["value"] = get_times_values(
-                sim, {"isotherm": experiment["isotherm"]}
+                sim, {"output_path": experiment["output_path"]}
             )
 
         elif "csv" in experiment:
@@ -480,16 +500,16 @@ class Cache:
                 temp["factor"] = 1.0
             temp["valueFactor"] = temp["value"] * temp["factor"]
 
-        if "featuresAlt" in experiment:
-            self.altFeatures = True
-            self.altFeatureNames = [
-                altFeature["name"] for altFeature in experiment["featuresAlt"]
+        if "scoresAlt" in experiment:
+            self.altScores = True
+            self.altScoreNames = [
+                altFeature["name"] for altFeature in experiment["scoresAlt"]
             ]
 
-            self.add_units_features_alt(units_used, experiment["featuresAlt"])
+            self.add_units_features_alt(units_used, experiment["scoresAlt"])
 
         peak_maxes = []
-        for feature in experiment["features"]:
+        for feature in experiment["scores"]:
             featureName = feature["name"]
             featureType = feature["type"]
 
@@ -504,7 +524,7 @@ class Cache:
                     (
                         temp[featureName]["time"],
                         temp[featureName]["value"],
-                    ) = get_times_values(sim, {"isotherm": feature["isotherm"]})
+                    ) = get_times_values(sim, {"output_path": feature["output_path"]})
                 else:
                     dataLocal = numpy.loadtxt(feature["csv"], delimiter=",")
                     temp[featureName]["time"] = dataLocal[:, 0]
@@ -530,12 +550,12 @@ class Cache:
                 feature["start"] = featureStart = temp[featureName]["time"][0]
                 feature["stop"] = featureStop = temp[featureName]["time"][-1]
 
-            if "isotherm" in feature:
-                temp[featureName]["isotherm"] = feature["isotherm"]
+            if "output_path" in feature:
+                temp[featureName]["output_path"] = feature["output_path"]
             else:
-                temp[featureName]["isotherm"] = experiment["isotherm"]
+                temp[featureName]["output_path"] = experiment["output_path"]
 
-            self.add_units_isotherm(units_used, temp[featureName]["isotherm"])
+            self.add_units_isotherm(units_used, temp[featureName]["output_path"])
 
             temp[featureName]["selected"] = (
                 temp[featureName]["time"] >= featureStart
@@ -605,11 +625,11 @@ cache = Cache()
 def get_times_values(simulation, target):
     "simplified version of the function so that util does not have to be imported"
     times = simulation.root.output.solution.solution_times
-    isotherm = target["isotherm"]
+    output_path = target["output_path"]
 
-    if isinstance(isotherm, list):
-        values = numpy.sum([simulation[i] for i in isotherm], 0)
+    if isinstance(output_path, list):
+        values = numpy.sum([simulation[i] for i in output_path], 0)
     else:
-        values = simulation[isotherm]
+        values = simulation[output_path]
 
     return times, values
