@@ -1,11 +1,10 @@
-import CADETMatch.util as util
-import CADETMatch.pareto as pareto
-
-from deap import creator
-from deap import tools
-from deap import base
 import array
 
+from deap import base, creator, tools
+
+import CADETMatch.pareto as pareto
+import CADETMatch.util as util
+
 meta_hof = pareto.ParetoFrontMeta(similar=pareto.similar, similar_fit=pareto.similar_fit_meta(cache),
                                           slice_object=cache.meta_slice)
 
