@@ -28,10 +28,10 @@ def main(map_function):
     # grad.setupTemplates(cache)
     hof = evo.run(cache)
 
-    multiprocessing.get_logger().info("altFeatures %s", cache.altFeatures)
-    multiprocessing.get_logger().info("altFeatureNames %s", cache.altFeatureNames)
+    multiprocessing.get_logger().info("altScoress %s", cache.altScores)
+    multiprocessing.get_logger().info("altScoreNames %s", cache.altScoreNames)
 
-    if cache.altFeatures:
+    if cache.altScores:
         for name in cache.altFeatureNames:
             json_path = util.setupAltFeature(cache, name)
             setup(cache, json_path, map_function)
@@ -312,7 +312,7 @@ def setupTemplates(cache):
         template_path = Path(
             cache.settings["resultsDirMisc"], "template_%s_final.h5" % name
         )
-        template_final = Cadet(template.root.copy())
+        template_final = Cadet(template.root)
         template_final.filename = template_path.as_posix()
         if cache.dynamicTolerance:
             template_final.root.input.solver.time_integrator.abstol = (
@@ -372,8 +372,6 @@ def continue_mcmc(cache, map_function):
 if __name__ == "__main__":
     start = time.time()
     map_function = util.getMapFunction()
-    # import cProfile
-    # cProfile.run('main(map_function=map_function)', 'restats')
     main(map_function=map_function)
     multiprocessing.get_logger().info("System has finished")
     multiprocessing.get_logger().info(
