@@ -1,7 +1,8 @@
-import CADETMatch.util as util
-import CADETMatch.calc_coeff as calc_coeff
 from addict import Dict
 
+import CADETMatch.calc_coeff as calc_coeff
+import CADETMatch.util as util
+
 name = "AbsoluteHeight"
 
 """This score is NOT for optimization. It is needed for the MCMC algorithm in order to handle assymetric distributions"""
@@ -13,6 +14,9 @@ def get_settings(feature):
     settings.badScore = 0
     settings.meta_mask = False
     settings.count = 1
+    settings.graph_der = 0
+    settings.graph = 0
+    settings.graph_frac = 0
     return settings
 
 
@@ -20,7 +24,9 @@ def run(sim_data, feature):
     "similarity, value, start stop"
     selected = feature["selected"]
     exp_data_values = feature["value"][selected]
-    sim_time_values, sim_data_values = util.get_times_values(sim_data["simulation"], feature)
+    sim_time_values, sim_data_values = util.get_times_values(
+        sim_data["simulation"], feature
+    )
 
     ys = [0.0, 1.0]
     xs = [0.0, max(exp_data_values) * 0.9]
