@@ -1,10 +1,11 @@
-import CADETMatch.util as util
-import CADETMatch.score as score
-import scipy.stats
-import scipy.interpolate
 import numpy
+import scipy.interpolate
+import scipy.stats
 from addict import Dict
+
+import CADETMatch.score as score
 import CADETMatch.smoothing as smoothing
+import CADETMatch.util as util
 
 name = "ShapeSimple"
 
@@ -15,28 +16,44 @@ def get_settings(feature):
     settings.badScore = 0
     settings.meta_mask = True
     settings.count = 3
+    settings.graph_der = 1
+    settings.graph = 1
+    settings.graph_frac = 0
     return settings
 
 
 def run(sim_data, feature):
     "similarity, value, start stop"
-    sim_time_values, sim_data_values = util.get_times_values(sim_data["simulation"], feature)
+    sim_time_values, sim_data_values = util.get_times_values(
+        sim_data["simulation"], feature
+    )
     selected = feature["selected"]
 
     exp_data_values = feature["value"][selected]
     exp_time_values = feature["time"][selected]
 
     sim_data_values_smooth, sim_data_values_der_smooth = smoothing.full_smooth(
-        exp_time_values, sim_data_values, feature["critical_frequency"], feature["smoothing_factor"], feature["critical_frequency_der"]
+        exp_time_values,
+        sim_data_values,
+        feature["critical_frequency"],
+        feature["smoothing_factor"],
+        feature["critical_frequency_der"],
     )
 
     [high, low] = util.find_peak(exp_time_values, sim_data_values_smooth)
 
     time_high, value_high = high
 
-    pearson, diff_time = score.pearson_spline(exp_time_values, sim_data_values_smooth, feature["smooth_value"])
+    pearson, diff_time = score.pearson_spline(
+        exp_time_values, sim_data_values_smooth, feature["smooth_value"]
+    )
 
-    pearson_der, diff_time_der = score.pearson_spline(exp_time_values, sim_data_values_der_smooth, feature["smooth_value_der"])
+    pearson_der = score.pearson_offset(
+        diff_time,
+        exp_time_values,
+        sim_data_values_der_smooth,
+        feature["smooth_value_der"],
+    )
 
     temp = [pearson, feature["time_function"](numpy.abs(diff_time)), pearson_der]
     return (
@@ -52,8 +69,12 @@ def run(sim_data, feature):
 
 def setup(sim, feature, selectedTimes, selectedValues, CV_time, abstol, cache):
     name = "%s_%s" % (sim.root.experiment_name, feature["name"])
-    s, crit_fs, crit_fs_der = smoothing.find_smoothing_factors(selectedTimes, selectedValues, name, cache)
-    exp_data_values_smooth, exp_data_values_der_smooth = smoothing.full_smooth(selectedTimes, selectedValues, crit_fs, s, crit_fs_der)
+    s, crit_fs, crit_fs_der = smoothing.find_smoothing_factors(
+        selectedTimes, selectedValues, name, cache
+    )
+    exp_data_values_smooth, exp_data_values_der_smooth = smoothing.full_smooth(
+        selectedTimes, selectedValues, crit_fs, s, crit_fs_der
+    )
 
     temp = {}
     temp["peak"] = util.find_peak(selectedTimes, selectedValues)[0]
