@@ -11,10 +11,12 @@ __all__ = [
 
 
 __title__ = "CADETMatch"
-__summary__ = "CADETMatch is a parameter estimation and error modeling library for CADET"
+__summary__ = (
+    "CADETMatch is a parameter estimation and error modeling library for CADET"
+)
 __author__ = "William Heymann"
 __email__ = "w.heymann@fz-juelich.de"
 __license__ = "GNU General Public License v3 (GPLv3)"
 __copyright__ = "2020 %s" % __author__
-__version__ = "0.6.17"
+__version__ = "0.7.0"
 __uri__ = "https://github.com/modsim/CADET-Match"
